@@ -31,10 +31,10 @@ import paho.mqtt.client as mqtt
 import shortuuid
 import zmq
 
-from .constants import CONNECTION_PUB_URL, DEVICE_PUB_URL
+from .constants import CONNECTION_PUB_URL
 
 
-class Dash():
+class DashControl():
     """Class to stare dash connection info
     """
     def get_state(self) -> str:
@@ -42,7 +42,7 @@ class Dash():
         """
         return ""
 
-    def get_cfg(self, data) -> str:
+    def get_cfg(self, data: list) -> str:
         """Returns the CFG info for the Dash connection. Called by iotdashboard app
 
         Parameters
@@ -60,10 +60,10 @@ class Dash():
             dashboard_id = data[2]
         except IndexError:
             return ""
-        cfg_str =f"\tCFG\t{dashboard_id}\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
+        cfg_str = f"\tCFG\t{dashboard_id}\t" + self.cntrl_type + "\t" + json.dumps(self._cfg) + "\n"
         return cfg_str
 
-    def get_cfg64(self, data) -> dict:
+    def get_cfg64(self, data: list) -> dict:
         """Returns the CFG dict for this TCP control
 
         Returns
@@ -76,6 +76,7 @@ class Dash():
     def __init__(self, control_id, username="", servername=""):
         self.cntrl_type = "DASHIO"
         self._cfg = {}
+        self._cfg["controlID"] = control_id
         self.control_id = control_id
         self.username = username
         self.servername = servername
@@ -135,6 +136,9 @@ class DashConnection(threading.Thread):
             for device_id in self._device_id_list:
                 control_topic = f"{self.username}/{device_id}/control"
                 self._dash_c.subscribe(control_topic, 0)
+            for device_id in self._device_id_rx_list:
+                data_topic = f"{self.username}/{device_id}/data"
+                self._dash_c.subscribe(data_topic, 0)
             self._send_dash_announce()
             logging.debug("connected OK")
         else:
@@ -149,7 +153,7 @@ class DashConnection(threading.Thread):
     def _on_message(self, client, obj, msg):
         data = str(msg.payload, "utf-8").strip()
         logging.debug("DASH RX:\n%s", data)
-        self.tx_zmq_pub.send_multipart([self._b_connection_id, b'1', msg.payload])
+        self.tx_zmq_pub.send_multipart([msg.payload, self._b_zmq_connection_uuid])
 
     def _on_subscribe(self, client, obj, mid, granted_qos):
         logging.debug("Subscribed: %s %s", str(mid), str(granted_qos))
@@ -167,20 +171,36 @@ class DashConnection(threading.Thread):
         """
         if device.device_id not in self._device_id_list:
             self._device_id_list.append(device.device_id)
-            device.rx_zmq_sub.connect(CONNECTION_PUB_URL.format(id=self._connection_id))
-            device.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, self._b_connection_id)
-            device.add_control(self.dash_control)
-
-            self.rx_zmq_sub.connect(DEVICE_PUB_URL.format(id=device.zmq_pub_id))
-            self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, device.zmq_pub_id)
-
+            device.register_connection(self)
             if self._connected:
                 control_topic = f"{self.username}/{device.device_id}/control"
                 self._dash_c.subscribe(control_topic, 0)
                 self._send_dash_announce()
 
+    def _add_device_rx(self, msg_dict):
+        """Connect to another device"""
+        device_id = msg_dict["deviceID"]
+        logging.debug("DASH DEVICE CONNECT: %s", device_id)
+        if device_id not in self._device_id_rx_list:
+            self._device_id_rx_list.append(device_id)
+            data_topic = f"{self.username}/{device_id}/data"
+            self._dash_c.subscribe(data_topic, 0)
+
+    def _del_device_rx(self, msg_dict):
+        device_id = msg_dict["deviceID"]
+        if device_id in self._device_id_rx_list:
+            data_topic = f"{self.username}/{device_id}/data"
+            self._dash_c.unsubscribe(data_topic)
+            logging.debug("DASH DEVICE_DISCONNECT: %s", device_id)
+            del self._device_id_rx_list[device_id]
+
     def _send_dash_announce(self):
-        self.tx_zmq_pub.send_multipart([b'COMMAND', b'1', b"send_announce"])
+        msg = {
+            'msgType': 'send_announce',
+            'connectionUUID': self.zmq_connection_uuid
+        }
+        logging.debug("DASH SEND ANNOUNCE: %s", msg)
+        self.tx_zmq_pub.send_multipart([b"COMMAND", json.dumps(msg).encode()])
 
     def set_connection(self, username: str, password: str):
         """Changes the connection to the DashIO server
@@ -204,7 +224,7 @@ class DashConnection(threading.Thread):
         host='dash.dashio.io',
         port=8883,
         use_ssl=True,
-        context=None
+        context: zmq.Context = None
     ):
         """
         Setups and manages a connection thread to the Dash Server.
@@ -228,9 +248,10 @@ class DashConnection(threading.Thread):
         self.context = context or zmq.Context.instance()
         self._connected = False
         self._disconnected = True
-        self._connection_id = shortuuid.uuid()
-        self._b_connection_id = self._connection_id.encode('utf-8')
+        self.zmq_connection_uuid = "DASH:" + shortuuid.uuid()
+        self._b_zmq_connection_uuid = self.zmq_connection_uuid.encode('utf-8')
         self._device_id_list = []
+        self._device_id_rx_list = []
         # self.LWD = "OFFLINE"
         self.running = True
         self.username = username
@@ -243,7 +264,7 @@ class DashConnection(threading.Thread):
         self._dash_c.on_disconnect = self._on_disconnect
         # self.dash_c.on_publish = self.__on_publish
         self._dash_c.on_subscribe = self._on_subscribe
-        self.dash_control = Dash(self._connection_id, username, host)
+        # self.connection_control = DashControl(self.zmq_connection_uuid, username, host)
         if use_ssl:
             self._dash_c.tls_set(
                 ca_certs=None,
@@ -265,30 +286,35 @@ class DashConnection(threading.Thread):
             except mqtt.socket.gaierror as error:
                 logging.debug("No connection to internet: %s", str(error))
         # Start subscribe, with QoS level 0
+        self.rx_zmq_sub = self.context.socket(zmq.SUB)
         self.disconnect_timeout = 15.0
         self.start()
-        time.sleep(1)
 
     def close(self):
         """Close the connection."""
         self.running = False
 
+    def _dash_command(self, msg_dict: dict):
+        logging.debug("TCP CMD: %s", msg_dict)
+        if msg_dict['msgType'] == 'connect':
+            self._add_device_rx(msg_dict)
+        if msg_dict['msgType'] == 'disconnect':
+            self._del_device_rx(msg_dict)
+
     def run(self):
         self._dash_c.loop_start()
 
         self.tx_zmq_pub = self.context.socket(zmq.PUB)
-        self.tx_zmq_pub.bind(CONNECTION_PUB_URL.format(id=self._connection_id))
+        self.tx_zmq_pub.bind(CONNECTION_PUB_URL.format(id=self.zmq_connection_uuid))
 
-        self.rx_zmq_sub = self.context.socket(zmq.SUB)
-
-        # Subscribe on ALL, and my connection
-        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALL")
-        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ANNOUNCE")
-        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, b"ALARM")
-        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, self._connection_id)
+        #  Subscribe on ALL, and my connection
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "ALL")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, "DASH")
+        self.rx_zmq_sub.setsockopt_string(zmq.SUBSCRIBE, self.zmq_connection_uuid)
         poller = zmq.Poller()
         poller.register(self.rx_zmq_sub, zmq.POLLIN)
-
+        data_topic = ""
+        control_type = ""
         while self.running:
             try:
                 socks = dict(poller.poll(50))
@@ -296,24 +322,36 @@ class DashConnection(threading.Thread):
                 break
 
             if self.rx_zmq_sub in socks:
-                [address, _, data] = self.rx_zmq_sub.recv_multipart()
+                try:
+                    [msg_to, data] = self.rx_zmq_sub.recv_multipart()
+                except ValueError:
+                    logging.debug("DASH value error")
+                    continue
                 if not data:
+                    logging.debug("DASH no data error")
+                    continue
+                # logging.debug("DASH: %s ,%s", msg_to, data)
+                if msg_to == b'COMMAND':
+                    logging.debug("DASH RX COMMAND")
+                    self._dash_command(json.loads(data))
                     continue
                 msg_l = data.split(b'\t')
+                if len(msg_l) > 3:
+                    control_type = msg_l[2]
                 try:
-                    device_id = msg_l[1].decode('utf-8').strip()
+                    device_id = msg_l[1].decode().strip()
                 except IndexError:
                     continue
-                if address == b'ALARM':
+                if control_type == b'ALM':
                     data_topic = f"{self.username}/{device_id}/alarm"
-                elif address == b"ANNOUNCE":
+                    control_type = ""
+                elif msg_to == b"DASH":
                     data_topic = f"{self.username}/{device_id}/announce"
                 else:
                     data_topic = f"{self.username}/{device_id}/data"
-                if self._connected:
-                    logging.debug("DASH TX:\n%s", data.decode('utf-8').rstrip())
-                    self._dash_c.publish(data_topic, data.decode('utf-8'))
-
+                if self._connected and data_topic:
+                    logging.debug("DASH TX:\n%s", data.decode().rstrip())
+                    self._dash_c.publish(data_topic, data.decode())
             if self._disconnected:
                 self.disconnect_timeout = min(self.disconnect_timeout, 900)
                 time.sleep(self.disconnect_timeout)
