@@ -21,13 +21,94 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .control import Control, ControlPosition, _get_title_position, _get_color, _get_bar_style
+from .control import Control, ControlPosition, ControlConfig, _get_title_position, _get_color, _get_bar_style
 from .enums import Color, SliderBarStyle, TitlePosition
 
 
+class SliderConfig(ControlConfig):
+    """SliderConfig"""
+    def __init__(
+        self,
+        control_id: str,
+        title: str,
+        title_position: TitlePosition,
+        bar_min: float,
+        bar_max: float,
+        red_value: float,
+        show_min_max: bool,
+        slider_enabled: bool,
+        send_only_on_release: bool,
+        bar_follows_slider: bool,
+        bar_color: Color,
+        knob_color: Color,
+        bar_style: SliderBarStyle,
+        control_position: ControlPosition,
+    ) -> None:
+        super().__init__(control_id, title, control_position, title_position)
+        self.cfg["redValue"] = red_value
+        self.cfg["min"] = bar_min
+        self.cfg["max"] = bar_max
+        self.cfg["showMinMax"] = show_min_max
+        self.cfg["sliderEnabled"] = slider_enabled
+        self.cfg["sendOnlyOnRelease"] = send_only_on_release
+        self.cfg["barFollowsSlider"] = bar_follows_slider
+        self.cfg["barColor"] = str(bar_color.value)
+        self.cfg["knobColor"] = str(knob_color.value)
+        self.cfg["barStyle"] = bar_style.value
+
+    @classmethod
+    def from_dict(cls, cfg_dict: dict):
+        """Instantiates SliderConfig from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        SliderConfig
+        """
+        tmp_cls = cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_title_position(cfg_dict["titlePosition"]),
+            cfg_dict["min"],
+            cfg_dict["max"],
+            cfg_dict["redValue"],
+            cfg_dict["showMinMax"],
+            cfg_dict["sliderEnabled"],
+            cfg_dict["sendOnlyOnRelease"],
+            cfg_dict["barFollowsSlider"],
+            _get_color(cfg_dict["barColor"]),
+            _get_color(cfg_dict["knobColor"]),
+            _get_bar_style(cfg_dict["barStyle"]),
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+        )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
+
+
 class Slider(Control):
     """Single slider bar control
     """
+
+    def add_config_columnar(self, config: SliderConfig):
+        if isinstance(config, SliderConfig):
+            config.cfg["min"] = self.bar_min
+            config.cfg["max"] = self.bar_max
+            config.cfg["redValue"] = self.red_value
+            config.cfg["ControlID"] = self.control_id
+            self._cfg_columnar.append(config)
+
+    def add_config_full_page(self, config: SliderConfig):
+        if isinstance(config, SliderConfig):
+            config.cfg["min"] = self.bar_min
+            config.cfg["max"] = self.bar_max
+            config.cfg["redValue"] = self.red_value
+            config.cfg["ControlID"] = self.control_id
+            self._cfg_columnar.append(config)
+
     def __init__(
         self,
         control_id: str,
@@ -78,27 +159,55 @@ class Slider(Control):
         bar_style : SliderBarStyle, optional
             bar style, by default SliderBarStyle.SEGMENTED
         """
-        super().__init__("SLDR", control_id, title=title, control_position=control_position, title_position=title_position)
+        super().__init__("SLDR", control_id)
+        self._cfg_columnar.append(
+            SliderConfig(
+                control_id,
+                title,
+                title_position,
+                bar_min,
+                bar_max,
+                red_value,
+                show_min_max,
+                slider_enabled,
+                send_only_on_release,
+                bar_follows_slider,
+                bar_color,
+                knob_color,
+                bar_style,
+                control_position
+            )
+        )
+
         self._control_id_bar = f"\t{{device_id}}\tBAR\t{control_id}\t"
 
         self._bar1_value = 0.0
         self._bar2_value = None
         self._slider_value = 0.0
 
-        self.bar_min = bar_min
-        self.bar_max = bar_max
-        self.red_value = red_value
-        self.show_min_max = show_min_max
-        self.slider_enabled = slider_enabled
-        self.send_only_on_release = send_only_on_release
-        self.bar_follows_slider = bar_follows_slider
-        self.bar_color = bar_color
-        self.bar_style = bar_style
-        self.knob_color = knob_color
         self._slider_state_str = self._control_hdr_str + f"{self._slider_value}\n"
         self._bar_state_str = self._control_id_bar + f"{self._bar1_value}\n"
         self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
+        self._bar_min = bar_min
+        self._bar_max = bar_max
+        self._red_value = red_value
+
+    @property
+    def bar_min(self):
+        """Returns the minimum bar value"""
+        return self._bar_min
+
+    @property
+    def bar_max(self):
+        """Returns the maximum bar value"""
+        return self._bar_max
+
+    @property
+    def red_value(self):
+        """Returns the red value"""
+        return self._red_value
+
     @classmethod
     def from_cfg_dict(cls, cfg_dict: dict):
         """Instatiates Slider from cfg dictionary
@@ -153,7 +262,7 @@ class Slider(Control):
             self._bar_state_str = self._control_id_bar + f"{self._bar1_value}\n"
         else:
             self._bar_state_str = self._control_id_bar + "{:.2f}\t{:.2f}\n".format(self._bar1_value, self._bar2_value)
-        self.message_tx_event(self._bar_state_str)
+        self._message_tx_event(self._bar_state_str)
         self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
     @property
@@ -174,7 +283,7 @@ class Slider(Control):
             self._bar_state_str = self._control_id_bar + f"{self._bar1_value}\n"
         else:
             self._bar_state_str = self._control_id_bar + "{:.2f}\t{:.2f}\n".format(self._bar1_value, self._bar2_value)
-        self.message_tx_event(self._bar_state_str)
+        self._message_tx_event(self._bar_state_str)
         self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
     @property
@@ -192,158 +301,5 @@ class Slider(Control):
     def slider_value(self, val: float):
         self._slider_value = val
         self._slider_state_str = self._control_hdr_str + f"{self._slider_value}\n"
-        self.message_tx_event(self._slider_state_str)
+        self._message_tx_event(self._slider_state_str)
         self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
-
-    @property
-    def bar_min(self) -> float:
-        """min bar value
-
-        Returns
-        -------
-        float
-            min bar value
-        """
-        return self._cfg["min"]
-
-    @bar_min.setter
-    def bar_min(self, val: float):
-        self._cfg["min"] = val
-
-    @property
-    def bar_max(self) -> float:
-        """max bar value
-
-        Returns
-        -------
-        float
-            max bar value
-        """
-        return self._cfg["max"]
-
-    @bar_max.setter
-    def bar_max(self, val: float):
-        self._cfg["max"] = val
-
-    @property
-    def red_value(self) -> float:
-        """Red value
-
-        Returns
-        -------
-        float
-            position of the red value
-        """
-        return self._cfg["redValue"]
-
-    @red_value.setter
-    def red_value(self, val: float):
-        self._cfg["redValue"] = val
-
-    @property
-    def show_min_max(self) -> bool:
-        """[summary]
-
-        Returns
-        -------
-        bool
-            [description]
-        """
-        return self._cfg["showMinMax"]
-
-    @show_min_max.setter
-    def show_min_max(self, val: bool):
-        self._cfg["showMinMax"] = val
-
-    @property
-    def slider_enabled(self) -> bool:
-        """Slider enabled
-
-        Returns
-        -------
-        bool
-            slider enabled
-        """
-        return self._cfg["sliderEnabled"]
-
-    @slider_enabled.setter
-    def slider_enabled(self, val: bool):
-        self._cfg["sliderEnabled"] = val
-
-    @property
-    def send_only_on_release(self) -> bool:
-        """Send slider position on release
-
-        Returns
-        -------
-        bool
-            Set to false for data firehose
-        """
-        return self._cfg["sendOnlyOnRelease"]
-
-    @send_only_on_release.setter
-    def send_only_on_release(self, val: bool):
-        self._cfg["sendOnlyOnRelease"] = val
-
-    @property
-    def bar_follows_slider(self) -> bool:
-        """Set bar follows slider
-
-        Returns
-        -------
-        bool
-            Set to True for bar follows slider
-        """
-        return self._cfg["barFollowsSlider"]
-
-    @bar_follows_slider.setter
-    def bar_follows_slider(self, val: bool):
-        self._cfg["barFollowsSlider"] = val
-
-    @property
-    def bar_color(self) -> Color:
-        """bar color
-
-        Returns
-        -------
-        Color
-            The color of the bar
-        """
-        return self._bar_color
-
-    @bar_color.setter
-    def bar_color(self, val: Color):
-        self._bar_color = val
-        self._cfg["barColor"] = str(val.value)
-
-    @property
-    def bar_style(self) -> SliderBarStyle:
-        """Slider bar style
-
-        Returns
-        -------
-        SliderBarStyle
-            Type of slider to display
-        """
-        return self._bar_style
-
-    @bar_style.setter
-    def bar_style(self, val: SliderBarStyle):
-        self._bar_style = val
-        self._cfg["barStyle"] = val.value
-
-    @property
-    def knob_color(self) -> Color:
-        """Color of the slider Knob
-
-        Returns
-        -------
-        Color
-            slider knob color
-        """
-        return self._knob_color
-
-    @knob_color.setter
-    def knob_color(self, val: Color):
-        self._knob_color = val
-        self._cfg["knobColor"] = str(val.value)
